fn drain_side<D, T, R>(
head: &mut Column<(D, T, R)>,
pos: &mut usize,
list: &mut IntoIter<Column<(D, T, R)>>,
result: &mut Column<(D, T, R)>,
output: &mut Vec<Column<(D, T, R)>>,
stash: &mut Vec<Column<(D, T, R)>>,
)Expand description
Drain remaining items from one side into result / output.
Copies the partially-consumed head into result via merge_from’s 1-input
path, then appends remaining full chunks directly to output without
per-element copy.